@@ -54,8 +54,8 @@ wmw.paired.replicates.test=function(X,Y
     } else {
         #### save rng state before set.seed in order to restore before exiting this function
         save.seed <- try(get(".Random.seed", .GlobalEnv), silent=TRUE) 
-        if (class(save.seed)=="try-error") { set.seed(1); save.seed <- get(".Random.seed", .GlobalEnv) }                        
-    
+        if (inherits(save.seed,"try-error")) { set.seed(1); save.seed <- get(".Random.seed", .GlobalEnv) }                        
+        
         # permutation method like that in Elena except two-sided
         if(useC) {
             set.seed(1) # so that it can be repeated
